diff mbox series

[14/15] modpost: rename alias symbol for MODULE_DEVICE_TABLE()

Message ID 20241119235705.1576946-14-masahiroy@kernel.org (mailing list archive)
State New
Headers show
Series [01/15] modpost: remove incorrect code in do_eisa_entry() | expand

Commit Message

Masahiro Yamada Nov. 19, 2024, 11:56 p.m. UTC
This commit renames the alias symbol, __mod_<type>__<name>_device_table
to __mod_device_table__<type>__<name>.

This change simplifies the code slightly, as there is no longer a need
to check both the prefix and suffix.

Signed-off-by: Masahiro Yamada <masahiroy@kernel.org>
---

 include/linux/module.h   |  2 +-
 scripts/mod/file2alias.c | 17 +++++++----------
 2 files changed, 8 insertions(+), 11 deletions(-)
diff mbox series

Patch

diff --git a/include/linux/module.h b/include/linux/module.h
index 88ecc5e9f523..3dd79a3d0cbf 100644
--- a/include/linux/module.h
+++ b/include/linux/module.h
@@ -247,7 +247,7 @@  extern void cleanup_module(void);
 #ifdef MODULE
 /* Creates an alias so file2alias.c can find device table. */
 #define MODULE_DEVICE_TABLE(type, name)					\
-extern typeof(name) __mod_##type##__##name##_device_table		\
+extern typeof(name) __mod_device_table__##type##__##name		\
   __attribute__ ((unused, alias(__stringify(name))))
 #else  /* !MODULE */
 #define MODULE_DEVICE_TABLE(type, name)
diff --git a/scripts/mod/file2alias.c b/scripts/mod/file2alias.c
index 2374737b9d22..b1291cc7bd80 100644
--- a/scripts/mod/file2alias.c
+++ b/scripts/mod/file2alias.c
@@ -121,7 +121,7 @@  typedef struct {
 #include "../../include/linux/mod_devicetable.h"
 
 struct devtable {
-	const char *device_id; /* name of table, __mod_<name>__*_device_table. */
+	const char *device_id;
 	unsigned long id_size;
 	void (*do_entry)(struct module *mod, void *symval);
 };
@@ -188,7 +188,7 @@  static void device_id_check(const char *modname, const char *device_id,
 	int i;
 
 	if (size % id_size || size < id_size) {
-		fatal("%s: sizeof(struct %s_device_id)=%lu is not a modulo of the size of section __mod_%s__<identifier>_device_table=%lu.\n"
+		fatal("%s: sizeof(struct %s_device_id)=%lu is not a modulo of the size of section __mod_device_table__%s__<identifier>=%lu.\n"
 		      "Fix definition of struct %s_device_id in mod_devicetable.h\n",
 		      modname, device_id, id_size, device_id, size, device_id);
 	}
@@ -1503,6 +1503,7 @@  void handle_moddevtable(struct module *mod, struct elf_info *info,
 	char *zeros = NULL;
 	const char *type, *name;
 	size_t typelen;
+	static const char *prefix = "__mod_device_table__";
 
 	/* We're looking for a section relative symbol */
 	if (!sym->st_shndx || get_secindex(info, sym) >= info->num_sections)
@@ -1512,15 +1513,11 @@  void handle_moddevtable(struct module *mod, struct elf_info *info,
 	if (ELF_ST_TYPE(sym->st_info) != STT_OBJECT)
 		return;
 
-	/* All our symbols are of form __mod_<type>__<name>_device_table. */
-	if (!strstarts(symname, "__mod_"))
-		return;
-	type = symname + strlen("__mod_");
-	typelen = strlen(type);
-	if (typelen < strlen("_device_table"))
-		return;
-	if (strcmp(type + typelen - strlen("_device_table"), "_device_table"))
+	/* All our symbols are of form __mod_device_table__<type>__<name>. */
+	if (!strstarts(symname, prefix))
 		return;
+	type = symname + strlen(prefix);
+
 	name = strstr(type, "__");
 	if (!name)
 		return;